@@ -2,7 +2,7 @@
  * css.c: Functions for DVD authentication and descrambling
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: css.c,v 1.15 2002/08/10 21:19:55 sam Exp $
+ * $Id: css.c,v 1.17 2002/10/10 21:40:41 massiot Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *         Hkan Hjort <d95hjort@dtek.chalmers.se>
@@ -83,13 +83,7 @@ int _dvdcss_test( dvdcss_t dvdcss )
         /* Since it's the first ioctl we try to issue, we add a notice */
         _dvdcss_error( dvdcss, "css error: ioctl_ReadCopyright failed, "
                        "make sure there is a DVD in the drive, and that "
-                       "you have used the correct device node."
-#if defined( WIN32 )
-                       "\nAlso note that if you are using Windows NT/2000/XP "
-                       "you need to have administrator priviledges to be able "
-                       "to use ioctls."
-#endif
-                     );
+                       "you have used the correct device node." );
 
         return i_ret;
     }
@@ -397,9 +391,12 @@ int _dvdcss_disckey( dvdcss_t dvdcss )
                 break;
             }
             _dvdcss_debug( dvdcss, "failed to decrypt the disc key, "
-                                   "trying to crack it instead" );
+                                   "faulty drive/kernel? "
+                                   "cracking title keys instead" );
 
-            /* Fallback */
+            /* Fallback, but not to DISC as the disc key might be faulty */
+            dvdcss->i_method = DVDCSS_METHOD_TITLE;
+            break;
 
         case DVDCSS_METHOD_DISC:
 
@@ -413,6 +410,7 @@ int _dvdcss_disckey( dvdcss_t dvdcss )
                 break;
             }
             _dvdcss_debug( dvdcss, "failed to crack the disc key" );
+            memset( p_disc_key, 0, KEY_SIZE );
             dvdcss->i_method = DVDCSS_METHOD_TITLE;
             break;
 
@@ -948,7 +946,7 @@ static int DecryptDiscKey( u8 const *p_struct_disckey, dvd_key_t p_disc_key )
             DecryptKey( 0, p_disc_key, p_struct_disckey, p_verify );
 
             /* If the position / player key pair worked then return. */
-            if( memcmp( p_disc_key, p_verify, 5 ) == 0 )
+            if( memcmp( p_disc_key, p_verify, KEY_SIZE ) == 0 )
             {
                 return 0;
             }
@@ -958,6 +956,7 @@ static int DecryptDiscKey( u8 const *p_struct_disckey, dvd_key_t p_disc_key )
 
     /* Have tried all combinations of positions and keys, 
      * and we still didn't succeed. */
+    memset( p_disc_key, 0, KEY_SIZE );
     return -1;
 }
 
